@@ -18,26 +18,25 @@
 #include <errno.h>
 #include <stdio.h>
 
-typedef char *hashtab_key_t;		/* generic key type */
-typedef void *hashtab_datum_t;		/* generic datum type */
+typedef char *hashtab_key_t;	/* generic key type */
+typedef void *hashtab_datum_t;	/* generic datum type */
 
 typedef struct hashtab_node *hashtab_ptr_t;
 
 typedef struct hashtab_node {
 	hashtab_key_t key;
 	hashtab_datum_t datum;
-	hashtab_ptr_t next;	
+	hashtab_ptr_t next;
 } hashtab_node_t;
 
 typedef struct hashtab_val {
-	hashtab_ptr_t *htable; /* hash table */
-	unsigned int size; /* number of slots in hash table */
-	uint32_t nel;  	  /* number of elements in hash table */
-	unsigned int (*hash_value) (struct hashtab_val *h, hashtab_key_t key); /* hash function */
-	int (*keycmp) (struct hashtab_val *h, hashtab_key_t key1, hashtab_key_t key2); /* key comparison function */
+	hashtab_ptr_t *htable;	/* hash table */
+	unsigned int size;	/* number of slots in hash table */
+	uint32_t nel;		/* number of elements in hash table */
+	unsigned int (*hash_value) (struct hashtab_val * h, hashtab_key_t key);	/* hash function */
+	int (*keycmp) (struct hashtab_val * h, hashtab_key_t key1, hashtab_key_t key2);	/* key comparison function */
 } hashtab_val_t;
 
-
 typedef hashtab_val_t *hashtab_t;
 
 /* Define status codes for hash table functions */
@@ -52,17 +51,13 @@ typedef hashtab_val_t *hashtab_t;
    Returns NULL if insufficent space is available or
    the new hash table otherwise.
  */
-extern hashtab_t hashtab_create(
-	unsigned int (*hash_value) (
-		hashtab_t h,
-		const hashtab_key_t key),
-
-	int (*keycmp) (
-		hashtab_t h,
-		const hashtab_key_t key1,
-		const hashtab_key_t key2),
-	
-	unsigned int size);
+extern hashtab_t hashtab_create(unsigned int (*hash_value) (hashtab_t h,
+							    const hashtab_key_t
+							    key),
+				int (*keycmp) (hashtab_t h,
+					       const hashtab_key_t key1,
+					       const hashtab_key_t key2),
+				unsigned int size);
 /*
    Inserts the specified (key, datum) pair into the specified hash table.
 
@@ -81,10 +76,9 @@ extern int hashtab_insert(hashtab_t h, hashtab_key_t k, hashtab_datum_t d);
    HASHTAB_SUCCESS otherwise.
  */
 extern int hashtab_remove(hashtab_t h, hashtab_key_t k,
-		   void (*destroy) (hashtab_key_t k,
-				    hashtab_datum_t d,
-				    void *args),
-		   void *args);
+			  void (*destroy) (hashtab_key_t k,
+					   hashtab_datum_t d,
+					   void *args), void *args);
 
 /*
    Insert or replace the specified (key, datum) pair in the specified
@@ -96,10 +90,9 @@ extern int hashtab_remove(hashtab_t h, hashtab_key_t k,
    HASHTAB_SUCCESS otherwise.
  */
 extern int hashtab_replace(hashtab_t h, hashtab_key_t k, hashtab_datum_t d,
-		    void (*destroy) (hashtab_key_t k,
-				     hashtab_datum_t d,
-				     void *args),
-		    void *args);
+			   void (*destroy) (hashtab_key_t k,
+					    hashtab_datum_t d,
+					    void *args), void *args);
 
 /*
    Searches for the entry with the specified key in the hash table.
@@ -107,9 +100,7 @@ extern int hashtab_replace(hashtab_t h, hashtab_key_t k, hashtab_datum_t d,
    Returns NULL if no entry has the specified key or
    the datum of the entry otherwise.
  */
-extern hashtab_datum_t hashtab_search(
-	hashtab_t h, 
-	const hashtab_key_t k);
+extern hashtab_datum_t hashtab_search(hashtab_t h, const hashtab_key_t k);
 
 /*
    Destroys the specified hash table.
@@ -128,10 +119,9 @@ extern void hashtab_destroy(hashtab_t h);
    return to its caller.
  */
 extern int hashtab_map(hashtab_t h,
-		int (*apply) (hashtab_key_t k,
-			      hashtab_datum_t d,
-			      void *args),
-		void *args);
+		       int (*apply) (hashtab_key_t k,
+				     hashtab_datum_t d,
+				     void *args), void *args);
 
 /*
    Same as hashtab_map, except that if apply returns a non-zero status,
@@ -139,16 +129,14 @@ extern int hashtab_map(hashtab_t h,
    destroy function will be applied to (key,datum,args).
  */
 extern void hashtab_map_remove_on_error(hashtab_t h,
-				 int (*apply) (hashtab_key_t k,
-					       hashtab_datum_t d,
-					       void *args),
-				 void (*destroy) (hashtab_key_t k,
-						  hashtab_datum_t d,
-						  void *args),
-				 void *args);
+					int (*apply) (hashtab_key_t k,
+						      hashtab_datum_t d,
+						      void *args),
+					void (*destroy) (hashtab_key_t k,
+							 hashtab_datum_t d,
+							 void *args),
+					void *args);
 
 extern void hashtab_hash_eval(hashtab_t h, char *tag);
 
-
 #endif
-
