@@ -26,14 +26,17 @@
 
 #include "private.h"
 
+#undef min
+#define min(a,b) (((a) < (b)) ? (a) : (b))
 
 /* move all type rules to top of t/f lists to help kernel on evaluation */
-static void cond_optimize(cond_av_list_t **l) {
-	cond_av_list_t *top, *p,*cur;
+static void cond_optimize(cond_av_list_t ** l)
+{
+	cond_av_list_t *top, *p, *cur;
 
 	top = p = cur = *l;
 
-	while(cur) {
+	while (cur) {
 		if ((cur->node->key.specified & AVTAB_TYPE) && (top != cur)) {
 			p->next = cur->next;
 			cur->next = top;
@@ -41,14 +44,15 @@ static void cond_optimize(cond_av_list_t **l) {
 			cur = p->next;
 		} else {
 			p = cur;
-			cur = cur->next; 
+			cur = cur->next;
 		}
 	}
 	*l = top;
 }
 
 /* reorder t/f lists for kernel */
-void cond_optimize_lists(cond_list_t* cl) {
+void cond_optimize_lists(cond_list_t * cl)
+{
 	cond_list_t *n;
 
 	for (n = cl; n != NULL; n = n->next) {
@@ -57,50 +61,58 @@ void cond_optimize_lists(cond_list_t* cl) {
 	}
 }
 
-
-static int bool_present(unsigned int target, unsigned int bools[], unsigned int num_bools) {
+static int bool_present(unsigned int target, unsigned int bools[],
+			unsigned int num_bools)
+{
 	unsigned int i = 0;
 	int ret = 1;
 
 	if (num_bools > COND_MAX_BOOLS) {
 		return 0;
 	}
-	while( i < num_bools && target != bools[i]) i++;
-	if (i == num_bools) ret = 0; /* got to end w/o match */
+	while (i < num_bools && target != bools[i])
+		i++;
+	if (i == num_bools)
+		ret = 0;	/* got to end w/o match */
 	return ret;
 }
 
-static int same_bools(cond_node_t *a, cond_node_t *b) {
+static int same_bools(cond_node_t * a, cond_node_t * b)
+{
 	unsigned int i, x;
-	
+
 	x = a->nbools;
 
 	/* same number of bools? */
-	if (x != b->nbools) return 0;
+	if (x != b->nbools)
+		return 0;
 
 	/* make sure all the bools in a are also in b */
-	for(i = 0; i < x; i++) if (!bool_present(a->bool_ids[i], b->bool_ids, x)) return 0;
+	for (i = 0; i < x; i++)
+		if (!bool_present(a->bool_ids[i], b->bool_ids, x))
+			return 0;
 	return 1;
 }
 
 /*
  * Determine if two conditional expressions are equal. 
  */
-static int cond_expr_equal(cond_node_t *a, cond_node_t *b)
+int cond_expr_equal(cond_node_t * a, cond_node_t * b)
 {
 	cond_expr_t *cur_a, *cur_b;
-		
+
 	if (a == NULL || b == NULL)
 		return 0;
 
-	if(a->nbools != b->nbools) return 0;
+	if (a->nbools != b->nbools)
+		return 0;
 
 	/* if exprs have <= COND_MAX_BOOLS we can check the precompute values
 	 * for the expressions.
 	 */
-	if (a->nbools <= COND_MAX_BOOLS && b->nbools <= COND_MAX_BOOLS)	    
-	{
-		if(!same_bools(a,b)) return 0;
+	if (a->nbools <= COND_MAX_BOOLS && b->nbools <= COND_MAX_BOOLS) {
+		if (!same_bools(a, b))
+			return 0;
 		return (a->expr_pre_comp == b->expr_pre_comp);
 	}
 
@@ -129,53 +141,55 @@ static int cond_expr_equal(cond_node_t *a, cond_node_t *b)
  * pointer to the existing node, setting 'was_created' to 0.
  * Otherwise create a new one and return it, setting 'was_created' to
  * 1. */
-cond_node_t *cond_node_find(policydb_t *p,
-                            cond_node_t *needle, cond_node_t *haystack,
-                            int *was_created) {
+cond_node_t *cond_node_find(policydb_t * p,
+			    cond_node_t * needle, cond_node_t * haystack,
+			    int *was_created)
+{
 	cond_node_t *new_node;
 	unsigned int i;
 
-	while(haystack) {
-		if (cond_expr_equal(needle,haystack)) {
-                        *was_created = 0;
-                        return haystack;
-                }
+	while (haystack) {
+		if (cond_expr_equal(needle, haystack)) {
+			*was_created = 0;
+			return haystack;
+		}
 		haystack = haystack->next;
 	}
-        *was_created = 1;
-        new_node = (cond_node_t *)malloc(sizeof (cond_node_t));
-        if (!new_node) {
-                return NULL;
-        }
-        memset(new_node, 0, sizeof(cond_node_t));
-        new_node->expr = cond_copy_expr(needle->expr);
-        if (!new_node->expr) {
-		free(new_node);
-                return NULL;
+	*was_created = 1;
+	new_node = (cond_node_t *) malloc(sizeof(cond_node_t));
+	if (!new_node) {
+		return NULL;
 	}
-        new_node->cur_state = cond_evaluate_expr(p, new_node->expr);
-        new_node->nbools = needle->nbools;
-        for (i = 0; i < needle->nbools; i++)
-                new_node->bool_ids[i] = needle->bool_ids[i];
-        new_node->expr_pre_comp = needle->expr_pre_comp;
-        new_node->true_list = NULL;
-        new_node->false_list = NULL;
-        new_node->avtrue_list = NULL;
-        new_node->avfalse_list = NULL;
-        return new_node;
+	memset(new_node, 0, sizeof(cond_node_t));
+	new_node->expr = cond_copy_expr(needle->expr);
+	if (!new_node->expr) {
+		free(new_node);
+		return NULL;
+	}
+	new_node->cur_state = cond_evaluate_expr(p, new_node->expr);
+	new_node->nbools = needle->nbools;
+	for (i = 0; i < min(needle->nbools, COND_MAX_BOOLS); i++)
+		new_node->bool_ids[i] = needle->bool_ids[i];
+	new_node->expr_pre_comp = needle->expr_pre_comp;
+	new_node->true_list = NULL;
+	new_node->false_list = NULL;
+	new_node->avtrue_list = NULL;
+	new_node->avfalse_list = NULL;
+	return new_node;
 }
 
 /* return either a pre-existing matching node or create a new node */
-cond_node_t *cond_node_search(policydb_t *p, cond_node_t *list, cond_node_t *cn)
+cond_node_t *cond_node_search(policydb_t * p, cond_node_t * list,
+			      cond_node_t * cn)
 {
-        int was_created;
-        cond_node_t *result = cond_node_find(p, cn, list, &was_created);
-        if (result != NULL && was_created) {
-                /* add conditional node to policy list */
-                result->next = p->cond_list;
-                p->cond_list = result;
-        }
-        return result;
+	int was_created;
+	cond_node_t *result = cond_node_find(p, cn, list, &was_created);
+	if (result != NULL && was_created) {
+		/* add conditional node to policy list */
+		result->next = p->cond_list;
+		p->cond_list = result;
+	}
+	return result;
 }
 
 /*
@@ -184,7 +198,7 @@ cond_node_t *cond_node_search(policydb_t *p, cond_node_t *list, cond_node_t *cn)
  * or undefined (-1). Undefined occurs when the expression
  * exceeds the stack depth of COND_EXPR_MAXDEPTH.
  */
-int cond_evaluate_expr(policydb_t *p, cond_expr_t *expr)
+int cond_evaluate_expr(policydb_t * p, cond_expr_t * expr)
 {
 
 	cond_expr_t *cur;
@@ -243,30 +257,30 @@ int cond_evaluate_expr(policydb_t *p, cond_expr_t *expr)
 	return s[0];
 }
 
-cond_expr_t *cond_copy_expr(cond_expr_t *expr)
+cond_expr_t *cond_copy_expr(cond_expr_t * expr)
 {
-        cond_expr_t *cur, *head, *tail, *new_expr;
-        tail = head = NULL;
-        cur = expr;
-        while (cur) {
-                new_expr = (cond_expr_t*)malloc(sizeof(cond_expr_t));
-                if (!new_expr)
+	cond_expr_t *cur, *head, *tail, *new_expr;
+	tail = head = NULL;
+	cur = expr;
+	while (cur) {
+		new_expr = (cond_expr_t *) malloc(sizeof(cond_expr_t));
+		if (!new_expr)
 			goto free_head;
-                memset(new_expr, 0, sizeof(cond_expr_t));
+		memset(new_expr, 0, sizeof(cond_expr_t));
 
-                new_expr->expr_type = cur->expr_type;
-                new_expr->bool = cur->bool;
+		new_expr->expr_type = cur->expr_type;
+		new_expr->bool = cur->bool;
 
-                if (!head)
-                        head = new_expr;
-                if (tail)
-                        tail->next = new_expr;
-                tail = new_expr;
-                cur = cur->next;
-        }
-        return head;
+		if (!head)
+			head = new_expr;
+		if (tail)
+			tail->next = new_expr;
+		tail = new_expr;
+		cur = cur->next;
+	}
+	return head;
 
-free_head:
+      free_head:
 	while (head) {
 		tail = head->next;
 		free(head);
@@ -282,16 +296,17 @@ free_head:
  * list appropriately. If the result of the expression is undefined
  * all of the rules are disabled for safety.
  */
-static int evaluate_cond_node(policydb_t *p, cond_node_t *node)
+static int evaluate_cond_node(policydb_t * p, cond_node_t * node)
 {
 	int new_state;
-	cond_av_list_t* cur;
+	cond_av_list_t *cur;
 
 	new_state = cond_evaluate_expr(p, node->expr);
 	if (new_state != node->cur_state) {
 		node->cur_state = new_state;
 		if (new_state == -1)
-			printf("expression result was undefined - disabling all rules.\n");
+			printf
+			    ("expression result was undefined - disabling all rules.\n");
 		/* turn the rules on or off */
 		for (cur = node->true_list; cur != NULL; cur = cur->next) {
 			if (new_state <= 0) {
@@ -301,7 +316,7 @@ static int evaluate_cond_node(policydb_t *p, cond_node_t *node)
 			}
 		}
 
-		for (cur = node->false_list; cur != NULL; cur = cur->next) {	
+		for (cur = node->false_list; cur != NULL; cur = cur->next) {
 			/* -1 or 1 */
 			if (new_state) {
 				cur->node->key.specified &= ~AVTAB_ENABLED;
@@ -317,9 +332,9 @@ static int evaluate_cond_node(policydb_t *p, cond_node_t *node)
  * to expression and switch t and f. precompute expression for expressions with limited
  * number of bools.
  */
-int cond_normalize_expr(policydb_t *p, cond_node_t *cn)
+int cond_normalize_expr(policydb_t * p, cond_node_t * cn)
 {
-	cond_expr_t *ne,*e;
+	cond_expr_t *ne, *e;
 	cond_av_list_t *tmp;
 	unsigned int i, j, orig_value[COND_MAX_BOOLS];
 	int k;
@@ -328,22 +343,24 @@ int cond_normalize_expr(policydb_t *p, cond_node_t *cn)
 
 	cn->nbools = 0;
 
-	memset(cn->bool_ids, 0,sizeof(cn->bool_ids) );
+	memset(cn->bool_ids, 0, sizeof(cn->bool_ids));
 	cn->expr_pre_comp = 0x0;
 
 	/* take care of !expr case */
 	ne = NULL;
 	e = cn->expr;
-        
-        /* becuase it's RPN look at last element */
-	while(e->next != NULL) { 
-		ne = e; e = e->next;
+
+	/* becuase it's RPN look at last element */
+	while (e->next != NULL) {
+		ne = e;
+		e = e->next;
 	}
 	if (e->expr_type == COND_NOT) {
 		if (ne) {
-			ne->next = NULL; 
-		} else { /* ne should never be NULL */
-			printf("Found expr with no bools and only a ! - this should never happen.\n");
+			ne->next = NULL;
+		} else {	/* ne should never be NULL */
+			printf
+			    ("Found expr with no bools and only a ! - this should never happen.\n");
 			return -1;
 		}
 		/* swap the true and false lists */
@@ -353,14 +370,14 @@ int cond_normalize_expr(policydb_t *p, cond_node_t *cn)
 		tmp2 = cn->avtrue_list;
 		cn->avtrue_list = cn->avfalse_list;
 		cn->avfalse_list = tmp2;
-                
+
 		/* free the "not" node in the list */
 		free(e);
 	}
 
 	/* find all the bools in the expression */
-	for(e = cn->expr; e != NULL; e = e->next) {
-		switch(e->expr_type) { 
+	for (e = cn->expr; e != NULL; e = e->next) {
+		switch (e->expr_type) {
 		case COND_BOOL:
 			i = 0;
 			/* see if we've already seen this bool */
@@ -375,41 +392,46 @@ int cond_normalize_expr(policydb_t *p, cond_node_t *cn)
 		default:
 			break;
 		}
-	} 
- 
+	}
+
 	/* only precompute for exprs with <= COND_AX_BOOLS */
-	if (cn->nbools <=  COND_MAX_BOOLS) {
+	if (cn->nbools <= COND_MAX_BOOLS) {
 		/* save the default values for the bools so we can play with them */
-		for(i = 0; i < cn->nbools; i++) {
-			orig_value[i] = p->bool_val_to_struct[cn->bool_ids[i] - 1]->state;
+		for (i = 0; i < cn->nbools; i++) {
+			orig_value[i] =
+			    p->bool_val_to_struct[cn->bool_ids[i] - 1]->state;
 		}
-		
+
 		/* loop through all possible combinations of values for bools in expression */
-		for(test = 0x0; test < (0x1U << cn->nbools) ; test++) {
+		for (test = 0x0; test < (0x1U << cn->nbools); test++) {
 			/* temporarily set the value for all the bools in the
 			 * expression using the corr.  bit in test */
-			for(j = 0; j < cn->nbools; j++) {
-				p->bool_val_to_struct[cn->bool_ids[j] - 1]->state =
-					( test & (0x1 << j) ) ? 1 : 0;
+			for (j = 0; j < cn->nbools; j++) {
+				p->bool_val_to_struct[cn->bool_ids[j] -
+						      1]->state =
+				    (test & (0x1 << j)) ? 1 : 0;
 			}
 			k = cond_evaluate_expr(p, cn->expr);
 			if (k == -1) {
-				printf("While testing expression, expression result "
-				       "was undefined - this should never happen.\n");
+				printf
+				    ("While testing expression, expression result "
+				     "was undefined - this should never happen.\n");
 				return -1;
 			}
 			/* set the bit if expression evaluates true */
-			if (k) cn->expr_pre_comp |= 0x1 << test;
+			if (k)
+				cn->expr_pre_comp |= 0x1 << test;
 		}
-		
+
 		/* restore bool default values */
-		for(i = 0; i < cn->nbools; i++)
-			p->bool_val_to_struct[cn->bool_ids[i] - 1]->state = orig_value[i] ;
+		for (i = 0; i < cn->nbools; i++)
+			p->bool_val_to_struct[cn->bool_ids[i] - 1]->state =
+			    orig_value[i];
 	}
 	return 0;
 }
 
-int evaluate_conds(policydb_t *p)
+int evaluate_conds(policydb_t * p)
 {
 	int ret;
 	cond_node_t *cur;
@@ -422,7 +444,7 @@ int evaluate_conds(policydb_t *p)
 	return 0;
 }
 
-int cond_policydb_init(policydb_t *p)
+int cond_policydb_init(policydb_t * p)
 {
 	p->bool_val_to_struct = NULL;
 	p->cond_list = NULL;
@@ -432,7 +454,7 @@ int cond_policydb_init(policydb_t *p)
 	return 0;
 }
 
-void cond_av_list_destroy(cond_av_list_t *list)
+void cond_av_list_destroy(cond_av_list_t * list)
 {
 	cond_av_list_t *cur, *next;
 	for (cur = list; cur != NULL; cur = next) {
@@ -442,7 +464,8 @@ void cond_av_list_destroy(cond_av_list_t *list)
 	}
 }
 
-void cond_expr_destroy(cond_expr_t *expr) {
+void cond_expr_destroy(cond_expr_t * expr)
+{
 	cond_expr_t *cur_expr, *next_expr;
 
 	if (!expr)
@@ -454,33 +477,33 @@ void cond_expr_destroy(cond_expr_t *expr) {
 	}
 }
 
-void cond_node_destroy(cond_node_t *node)
+void cond_node_destroy(cond_node_t * node)
 {
 	if (!node)
 		return;
 
 	cond_expr_destroy(node->expr);
-        avrule_list_destroy(node->avtrue_list);
-        avrule_list_destroy(node->avfalse_list);
+	avrule_list_destroy(node->avtrue_list);
+	avrule_list_destroy(node->avfalse_list);
 	cond_av_list_destroy(node->true_list);
 	cond_av_list_destroy(node->false_list);
 }
 
-void cond_list_destroy(cond_list_t *list)
+void cond_list_destroy(cond_list_t * list)
 {
 	cond_node_t *next, *cur;
-	
+
 	if (list == NULL)
 		return;
 
 	for (cur = list; cur != NULL; cur = next) {
 		next = cur->next;
 		cond_node_destroy(cur);
-                free(cur);
+		free(cur);
 	}
 }
 
-void cond_policydb_destroy(policydb_t *p)
+void cond_policydb_destroy(policydb_t * p)
 {
 	if (p->bool_val_to_struct != NULL)
 		free(p->bool_val_to_struct);
@@ -488,18 +511,19 @@ void cond_policydb_destroy(policydb_t *p)
 	cond_list_destroy(p->cond_list);
 }
 
-int cond_init_bool_indexes(policydb_t *p)
+int cond_init_bool_indexes(policydb_t * p)
 {
 	if (p->bool_val_to_struct)
 		free(p->bool_val_to_struct);
-	p->bool_val_to_struct = (cond_bool_datum_t**)
-		malloc(p->p_bools.nprim * sizeof(cond_bool_datum_t*));
+	p->bool_val_to_struct = (cond_bool_datum_t **)
+	    malloc(p->p_bools.nprim * sizeof(cond_bool_datum_t *));
 	if (!p->bool_val_to_struct)
 		return -1;
 	return 0;
 }
 
-int cond_destroy_bool(hashtab_key_t key, hashtab_datum_t datum, void *p __attribute__ ((unused)))
+int cond_destroy_bool(hashtab_key_t key, hashtab_datum_t datum, void *p
+		      __attribute__ ((unused)))
 {
 	if (key)
 		free(key);
@@ -514,24 +538,26 @@ int cond_index_bool(hashtab_key_t key, hashtab_datum_t datum, void *datap)
 
 	booldatum = datum;
 	p = datap;
-	
-	if (!booldatum->value || booldatum->value > p->p_bools.nprim)
+
+	if (!booldatum->s.value || booldatum->s.value > p->p_bools.nprim)
 		return -EINVAL;
 
-	p->p_bool_val_to_name[booldatum->value - 1] = key;
-	p->bool_val_to_struct[booldatum->value -1] = booldatum;
+	p->p_bool_val_to_name[booldatum->s.value - 1] = key;
+	p->bool_val_to_struct[booldatum->s.value - 1] = booldatum;
 
 	return 0;
 }
 
-static int bool_isvalid(cond_bool_datum_t *b)
+static int bool_isvalid(cond_bool_datum_t * b)
 {
 	if (!(b->state == 0 || b->state == 1))
 		return 0;
 	return 1;
 }
 
-int cond_read_bool(policydb_t *p __attribute__ ((unused)), hashtab_t h, struct policy_file *fp)
+int cond_read_bool(policydb_t * p
+		   __attribute__ ((unused)), hashtab_t h,
+		   struct policy_file *fp)
 {
 	char *key = 0;
 	cond_bool_datum_t *booldatum;
@@ -546,14 +572,14 @@ int cond_read_bool(policydb_t *p __attribute__ ((unused)), hashtab_t h, struct p
 	if (!buf)
 		goto err;
 
-	booldatum->value = le32_to_cpu(buf[0]);
+	booldatum->s.value = le32_to_cpu(buf[0]);
 	booldatum->state = le32_to_cpu(buf[1]);
-	
+
 	if (!bool_isvalid(booldatum))
 		goto err;
 
 	len = le32_to_cpu(buf[2]);
-	
+
 	buf = next_entry(fp, len);
 	if (!buf)
 		goto err;
@@ -564,22 +590,23 @@ int cond_read_bool(policydb_t *p __attribute__ ((unused)), hashtab_t h, struct p
 	key[len] = 0;
 	if (hashtab_insert(h, key, booldatum))
 		goto err;
-	
+
 	return 0;
-err:
+      err:
 	cond_destroy_bool(key, booldatum, 0);
 	return -1;
 }
 
-struct cond_insertf_data 
-{
+struct cond_insertf_data {
 	struct policydb *p;
 	cond_av_list_t *other;
 	cond_av_list_t *head;
 	cond_av_list_t *tail;
 };
 
-static int cond_insertf(avtab_t *a __attribute__ ((unused)), avtab_key_t *k, avtab_datum_t *d, void *ptr)
+static int cond_insertf(avtab_t * a
+			__attribute__ ((unused)), avtab_key_t * k,
+			avtab_datum_t * d, void *ptr)
 {
 	struct cond_insertf_data *data = ptr;
 	struct policydb *p = data->p;
@@ -587,7 +614,6 @@ static int cond_insertf(avtab_t *a __attribute__ ((unused)), avtab_key_t *k, avt
 	avtab_ptr_t node_ptr;
 	uint8_t found;
 
-
 	/*
 	 * For type rules we have to make certain there aren't any
 	 * conflicting rules by searching the te_avtab and the
@@ -595,7 +621,8 @@ static int cond_insertf(avtab_t *a __attribute__ ((unused)), avtab_key_t *k, avt
 	 */
 	if (k->specified & AVTAB_TYPE) {
 		if (avtab_search(&p->te_avtab, k)) {
-			printf("security: type rule already exists outside of a conditional.");
+			printf
+			    ("security: type rule already exists outside of a conditional.");
 			goto err;
 		}
 		/*
@@ -609,8 +636,10 @@ static int cond_insertf(avtab_t *a __attribute__ ((unused)), avtab_key_t *k, avt
 		if (other) {
 			node_ptr = avtab_search_node(&p->te_cond_avtab, k);
 			if (node_ptr) {
-				if (avtab_search_node_next(node_ptr, k->specified)) {
-					printf("security: too many conflicting type rules.");
+				if (avtab_search_node_next
+				    (node_ptr, k->specified)) {
+					printf
+					    ("security: too many conflicting type rules.");
 					goto err;
 				}
 				found = 0;
@@ -621,13 +650,15 @@ static int cond_insertf(avtab_t *a __attribute__ ((unused)), avtab_key_t *k, avt
 					}
 				}
 				if (!found) {
-					printf("security: conflicting type rules.\n");
+					printf
+					    ("security: conflicting type rules.\n");
 					goto err;
 				}
 			}
-		} else {    
+		} else {
 			if (avtab_search(&p->te_cond_avtab, k)) {
-				printf("security: conflicting type rules when adding type rule for true.\n");
+				printf
+				    ("security: conflicting type rules when adding type rule for true.\n");
 				goto err;
 			}
 		}
@@ -638,7 +669,7 @@ static int cond_insertf(avtab_t *a __attribute__ ((unused)), avtab_key_t *k, avt
 		printf("security: could not insert rule.");
 		goto err;
 	}
-	node_ptr->parse_context = (void*)1;
+	node_ptr->parse_context = (void *)1;
 
 	list = malloc(sizeof(cond_av_list_t));
 	if (!list)
@@ -653,13 +684,14 @@ static int cond_insertf(avtab_t *a __attribute__ ((unused)), avtab_key_t *k, avt
 	data->tail = list;
 	return 0;
 
-err:
+      err:
 	cond_av_list_destroy(data->head);
 	data->head = NULL;
 	return -1;
 }
 
-static int cond_read_av_list(policydb_t *p, void *fp, cond_av_list_t **ret_list, cond_av_list_t *other)
+static int cond_read_av_list(policydb_t * p, void *fp,
+			     cond_av_list_t ** ret_list, cond_av_list_t * other)
 {
 	unsigned int i;
 	int rc;
@@ -683,7 +715,8 @@ static int cond_read_av_list(policydb_t *p, void *fp, cond_av_list_t **ret_list,
 	data.head = NULL;
 	data.tail = NULL;
 	for (i = 0; i < len; i++) {
-		rc = avtab_read_item(fp, p->policyvers, &p->te_cond_avtab, cond_insertf, &data);
+		rc = avtab_read_item(fp, p->policyvers, &p->te_cond_avtab,
+				     cond_insertf, &data);
 		if (rc)
 			return rc;
 
@@ -693,21 +726,23 @@ static int cond_read_av_list(policydb_t *p, void *fp, cond_av_list_t **ret_list,
 	return 0;
 }
 
-static int expr_isvalid(policydb_t *p, cond_expr_t *expr)
+static int expr_isvalid(policydb_t * p, cond_expr_t * expr)
 {
 	if (expr->expr_type <= 0 || expr->expr_type > COND_LAST) {
-		printf("security: conditional expressions uses unknown operator.\n");
+		printf
+		    ("security: conditional expressions uses unknown operator.\n");
 		return 0;
 	}
-	
+
 	if (expr->bool > p->p_bools.nprim) {
-		printf("security: conditional expressions uses unknown bool.\n");
+		printf
+		    ("security: conditional expressions uses unknown bool.\n");
 		return 0;
 	}
 	return 1;
 }
 
-static int cond_read_node(policydb_t *p, cond_node_t *node, void *fp)
+static int cond_read_node(policydb_t * p, cond_node_t * node, void *fp)
 {
 	uint32_t *buf;
 	int len, i;
@@ -718,7 +753,7 @@ static int cond_read_node(policydb_t *p, cond_node_t *node, void *fp)
 		goto err;
 
 	node->cur_state = le32_to_cpu(buf[0]);
-	
+
 	len = 0;
 	buf = next_entry(fp, sizeof(uint32_t));
 	if (!buf)
@@ -726,8 +761,8 @@ static int cond_read_node(policydb_t *p, cond_node_t *node, void *fp)
 
 	/* expr */
 	len = le32_to_cpu(buf[0]);
-	
-	for (i = 0; i < len; i++ ) {
+
+	for (i = 0; i < len; i++) {
 		buf = next_entry(fp, sizeof(uint32_t) * 2);
 		if (!buf)
 			goto err;
@@ -740,7 +775,7 @@ static int cond_read_node(policydb_t *p, cond_node_t *node, void *fp)
 
 		expr->expr_type = le32_to_cpu(buf[0]);
 		expr->bool = le32_to_cpu(buf[1]);
-		
+
 		if (!expr_isvalid(p, expr)) {
 			free(expr);
 			goto err;
@@ -753,11 +788,12 @@ static int cond_read_node(policydb_t *p, cond_node_t *node, void *fp)
 		}
 		last = expr;
 	}
-	
+
 	if (p->policy_type == POLICY_KERN) {
 		if (cond_read_av_list(p, fp, &node->true_list, NULL) != 0)
 			goto err;
-		if (cond_read_av_list(p, fp, &node->false_list, node->true_list) != 0)
+		if (cond_read_av_list(p, fp, &node->false_list, node->true_list)
+		    != 0)
 			goto err;
 	} else {
 		if (avrule_read_list(p, &node->avtrue_list, fp))
@@ -765,15 +801,15 @@ static int cond_read_node(policydb_t *p, cond_node_t *node, void *fp)
 		if (avrule_read_list(p, &node->avfalse_list, fp))
 			goto err;
 	}
-        
+
 	return 0;
-err:
+      err:
 	cond_node_destroy(node);
 	free(node);
 	return -1;
 }
 
-int cond_read_list(policydb_t *p, cond_list_t **list, void *fp)
+int cond_read_list(policydb_t * p, cond_list_t ** list, void *fp)
 {
 	cond_node_t *node, *last = NULL;
 	uint32_t *buf;
@@ -790,7 +826,7 @@ int cond_read_list(policydb_t *p, cond_list_t **list, void *fp)
 		if (!node)
 			goto err;
 		memset(node, 0, sizeof(cond_node_t));
-		
+
 		if (cond_read_node(p, node, fp) != 0)
 			goto err;
 
@@ -799,54 +835,56 @@ int cond_read_list(policydb_t *p, cond_list_t **list, void *fp)
 		} else {
 			last->next = node;
 		}
-		last = node;			
+		last = node;
 	}
 	return 0;
-err:
+      err:
 	return -1;
 }
 
 /* Determine whether additional permissions are granted by the conditional
  * av table, and if so, add them to the result 
  */
-void cond_compute_av(avtab_t *ctab, avtab_key_t *key, struct sepol_av_decision *avd)
+void cond_compute_av(avtab_t * ctab, avtab_key_t * key,
+		     struct sepol_av_decision *avd)
 {
 	avtab_ptr_t node;
-	
-	if(!ctab || !key || !avd) 
+
+	if (!ctab || !key || !avd)
 		return;
-		
-	for(node = avtab_search_node(ctab, key); node != NULL; 
-				node = avtab_search_node_next(node, key->specified)) {
-		if ( (uint16_t) (AVTAB_ALLOWED|AVTAB_ENABLED) ==
-		     (node->key.specified & (AVTAB_ALLOWED|AVTAB_ENABLED)))
+
+	for (node = avtab_search_node(ctab, key); node != NULL;
+	     node = avtab_search_node_next(node, key->specified)) {
+		if ((uint16_t) (AVTAB_ALLOWED | AVTAB_ENABLED) ==
+		    (node->key.specified & (AVTAB_ALLOWED | AVTAB_ENABLED)))
 			avd->allowed |= node->datum.data;
-		if ( (uint16_t) (AVTAB_AUDITDENY|AVTAB_ENABLED) ==
-		     (node->key.specified & (AVTAB_AUDITDENY|AVTAB_ENABLED)))
+		if ((uint16_t) (AVTAB_AUDITDENY | AVTAB_ENABLED) ==
+		    (node->key.specified & (AVTAB_AUDITDENY | AVTAB_ENABLED)))
 			/* Since a '0' in an auditdeny mask represents a 
 			 * permission we do NOT want to audit (dontaudit), we use
 			 * the '&' operand to ensure that all '0's in the mask
 			 * are retained (much unlike the allow and auditallow cases).
 			 */
 			avd->auditdeny &= node->datum.data;
-		if ( (uint16_t) (AVTAB_AUDITALLOW|AVTAB_ENABLED) ==
-		     (node->key.specified & (AVTAB_AUDITALLOW|AVTAB_ENABLED)))
+		if ((uint16_t) (AVTAB_AUDITALLOW | AVTAB_ENABLED) ==
+		    (node->key.specified & (AVTAB_AUDITALLOW | AVTAB_ENABLED)))
 			avd->auditallow |= node->datum.data;
 	}
-	return;	
+	return;
 }
 
-avtab_datum_t *cond_av_list_search(avtab_key_t *key, cond_av_list_t *cond_list)
+avtab_datum_t *cond_av_list_search(avtab_key_t * key,
+				   cond_av_list_t * cond_list)
 {
-	
+
 	cond_av_list_t *cur_av;
 
-	for(cur_av = cond_list; cur_av != NULL; cur_av = cur_av->next) {
-		
+	for (cur_av = cond_list; cur_av != NULL; cur_av = cur_av->next) {
+
 		if (cur_av->node->key.source_type == key->source_type &&
-		    cur_av->node->key.target_type == key->target_type && 
+		    cur_av->node->key.target_type == key->target_type &&
 		    cur_av->node->key.target_class == key->target_class)
-			
+
 			return &cur_av->node->datum;
 
 	}
