@@ -6,7 +6,7 @@
 
 /* Policy file interfaces. */
 
-int sepol_policy_file_create(sepol_policy_file_t **pf)
+int sepol_policy_file_create(sepol_policy_file_t ** pf)
 {
 	*pf = calloc(1, sizeof(sepol_policy_file_t));
 	if (!(*pf))
@@ -14,9 +14,8 @@ int sepol_policy_file_create(sepol_policy_file_t **pf)
 	return 0;
 }
 
-void sepol_policy_file_set_mem(sepol_policy_file_t *spf,
-			      char *data,
-			      size_t len)
+void sepol_policy_file_set_mem(sepol_policy_file_t * spf,
+			       char *data, size_t len)
 {
 	struct policy_file *pf = &spf->pf;
 	if (!len) {
@@ -30,8 +29,7 @@ void sepol_policy_file_set_mem(sepol_policy_file_t *spf,
 	return;
 }
 
-void sepol_policy_file_set_fp(sepol_policy_file_t *spf,
-			     FILE *fp)
+void sepol_policy_file_set_fp(sepol_policy_file_t * spf, FILE * fp)
 {
 	struct policy_file *pf = &spf->pf;
 	pf->type = PF_USE_STDIO;
@@ -39,8 +37,7 @@ void sepol_policy_file_set_fp(sepol_policy_file_t *spf,
 	return;
 }
 
-int sepol_policy_file_get_len(sepol_policy_file_t *spf,
-			      size_t *len)
+int sepol_policy_file_get_len(sepol_policy_file_t * spf, size_t * len)
 {
 	struct policy_file *pf = &spf->pf;
 	if (pf->type != PF_LEN)
@@ -49,20 +46,20 @@ int sepol_policy_file_get_len(sepol_policy_file_t *spf,
 	return 0;
 }
 
-void sepol_policy_file_set_handle(sepol_policy_file_t *pf,
-				  sepol_handle_t *handle)
+void sepol_policy_file_set_handle(sepol_policy_file_t * pf,
+				  sepol_handle_t * handle)
 {
 	pf->pf.handle = handle;
 }
 
-void sepol_policy_file_free(sepol_policy_file_t *pf)
+void sepol_policy_file_free(sepol_policy_file_t * pf)
 {
 	free(pf);
 }
 
 /* Policydb interfaces. */
 
-int sepol_policydb_create(sepol_policydb_t **sp)
+int sepol_policydb_create(sepol_policydb_t ** sp)
 {
 	policydb_t *p;
 	*sp = malloc(sizeof(sepol_policydb_t));
@@ -75,15 +72,17 @@ int sepol_policydb_create(sepol_policydb_t **sp)
 	}
 	return 0;
 }
+
 hidden_def(sepol_policydb_create)
 
-void sepol_policydb_free(sepol_policydb_t *p) 
+void sepol_policydb_free(sepol_policydb_t * p)
 {
 	if (!p)
 		return;
 	policydb_destroy(&p->p);
 	free(p);
 }
+
 hidden_def(sepol_policydb_free)
 
 int sepol_policy_kern_vers_min(void)
@@ -96,7 +95,7 @@ int sepol_policy_kern_vers_max(void)
 	return POLICYDB_VERSION_MAX;
 }
 
-int sepol_policydb_set_typevers(sepol_policydb_t *sp, unsigned int type)
+int sepol_policydb_set_typevers(sepol_policydb_t * sp, unsigned int type)
 {
 	struct policydb *p = &sp->p;
 	switch (type) {
@@ -114,7 +113,7 @@ int sepol_policydb_set_typevers(sepol_policydb_t *sp, unsigned int type)
 	return 0;
 }
 
-int sepol_policydb_set_vers(sepol_policydb_t *sp, unsigned int vers)
+int sepol_policydb_set_vers(sepol_policydb_t * sp, unsigned int vers)
 {
 	struct policydb *p = &sp->p;
 	switch (p->policy_type) {
@@ -124,7 +123,8 @@ int sepol_policydb_set_vers(sepol_policydb_t *sp, unsigned int vers)
 		break;
 	case POLICY_BASE:
 	case POLICY_MOD:
-		if (vers < MOD_POLICYDB_VERSION_MIN || vers > MOD_POLICYDB_VERSION_MAX)
+		if (vers < MOD_POLICYDB_VERSION_MIN
+		    || vers > MOD_POLICYDB_VERSION_MAX)
 			return -1;
 		break;
 	default:
@@ -134,33 +134,42 @@ int sepol_policydb_set_vers(sepol_policydb_t *sp, unsigned int vers)
 	return 0;
 }
 
-int sepol_policydb_read(sepol_policydb_t *p,
-			sepol_policy_file_t *pf)
+int sepol_policydb_read(sepol_policydb_t * p, sepol_policy_file_t * pf)
 {
 	return policydb_read(&p->p, &pf->pf, 0);
 }
 
-int sepol_policydb_write(sepol_policydb_t *p,
-			 sepol_policy_file_t *pf)
+int sepol_policydb_write(sepol_policydb_t * p, sepol_policy_file_t * pf)
 {
 	return policydb_write(&p->p, &pf->pf);
 }
 
-int sepol_policydb_from_image(sepol_handle_t *handle,
-			      void *data, size_t len, sepol_policydb_t *p)
+int sepol_policydb_from_image(sepol_handle_t * handle,
+			      void *data, size_t len, sepol_policydb_t * p)
 {
 	return policydb_from_image(handle, data, len, &p->p);
 }
 
-int sepol_policydb_to_image(sepol_handle_t *handle,
-			    sepol_policydb_t *p, void **newdata, 
-			    size_t *newlen)
+int sepol_policydb_to_image(sepol_handle_t * handle,
+			    sepol_policydb_t * p, void **newdata,
+			    size_t * newlen)
 {
 	return policydb_to_image(handle, &p->p, newdata, newlen);
 }
 
-int sepol_policydb_mls_enabled(
-	const sepol_policydb_t* p)  {
+int sepol_policydb_mls_enabled(const sepol_policydb_t * p)
+{
 
 	return p->p.mls;
 }
+
+/* 
+ * Enable compatibility mode for SELinux network checks iff
+ * the packet class is not defined in the policy.
+ */
+#define PACKET_CLASS_NAME "packet"
+int sepol_policydb_compat_net(const sepol_policydb_t * p)
+{
+	return (hashtab_search(p->p.p_classes.table, PACKET_CLASS_NAME) ==
+		NULL);
+}
