@@ -8,47 +8,43 @@
 #include <sepol/policydb/policydb.h>
 #include "port_internal.h"
 
-static inline int sepol2ipproto(
-	sepol_handle_t* handle,
-	int proto) {
+static inline int sepol2ipproto(sepol_handle_t * handle, int proto)
+{
 
-	switch(proto) {
-		case SEPOL_PROTO_TCP:
-			return IPPROTO_TCP;
-		case SEPOL_PROTO_UDP:
-			return IPPROTO_UDP;
-		default:
-			ERR(handle, "unsupported protocol %u", proto);
-			return STATUS_ERR;
+	switch (proto) {
+	case SEPOL_PROTO_TCP:
+		return IPPROTO_TCP;
+	case SEPOL_PROTO_UDP:
+		return IPPROTO_UDP;
+	default:
+		ERR(handle, "unsupported protocol %u", proto);
+		return STATUS_ERR;
 	}
 }
 
-static inline int ipproto2sepol(
-	sepol_handle_t* handle,
-	int proto) {
+static inline int ipproto2sepol(sepol_handle_t * handle, int proto)
+{
 
-	switch(proto) {
-		case IPPROTO_TCP:
-			return SEPOL_PROTO_TCP;
-		case IPPROTO_UDP:
-			return SEPOL_PROTO_UDP;
-		default:
-			ERR(handle, "invalid protocol %u "
-				"found in policy", proto);
-			return STATUS_ERR;
+	switch (proto) {
+	case IPPROTO_TCP:
+		return SEPOL_PROTO_TCP;
+	case IPPROTO_UDP:
+		return SEPOL_PROTO_UDP;
+	default:
+		ERR(handle, "invalid protocol %u " "found in policy", proto);
+		return STATUS_ERR;
 	}
 }
 
 /* Create a low level port structure from
  * a high level representation */
-static int port_from_record(
-	sepol_handle_t* handle,
-	const policydb_t* policydb,
-	ocontext_t** port,
-	const sepol_port_t* data) {
+static int port_from_record(sepol_handle_t * handle,
+			    const policydb_t * policydb,
+			    ocontext_t ** port, const sepol_port_t * data)
+{
 
-	ocontext_t* tmp_port = NULL;
-	context_struct_t* tmp_con = NULL;
+	ocontext_t *tmp_port = NULL;
+	context_struct_t *tmp_con = NULL;
 	int tmp_proto;
 
 	int low = sepol_port_get_low(data);
@@ -56,9 +52,9 @@ static int port_from_record(
 	int proto = sepol_port_get_proto(data);
 
 	tmp_port = (ocontext_t *) calloc(1, sizeof(ocontext_t));
-	if (!tmp_port) 
+	if (!tmp_port)
 		goto omem;
-	
+
 	/* Process protocol */
 	tmp_proto = sepol2ipproto(handle, proto);
 	if (tmp_proto < 0)
@@ -70,14 +66,13 @@ static int port_from_record(
 	tmp_port->u.port.high_port = high;
 	if (tmp_port->u.port.low_port > tmp_port->u.port.high_port) {
 		ERR(handle, "low port %d exceeds high port %d",
-			tmp_port->u.port.low_port, 
-			tmp_port->u.port.high_port);
+		    tmp_port->u.port.low_port, tmp_port->u.port.high_port);
 		goto err;
 	}
 
 	/* Context */
-	if (context_from_record(handle, policydb, &tmp_con, 
-		sepol_port_get_con(data)) < 0)
+	if (context_from_record(handle, policydb, &tmp_con,
+				sepol_port_get_con(data)) < 0)
 		goto err;
 	context_cpy(&tmp_port->context[0], tmp_con);
 	context_destroy(tmp_con);
@@ -87,35 +82,34 @@ static int port_from_record(
 	*port = tmp_port;
 	return STATUS_SUCCESS;
 
-	omem:
+      omem:
 	ERR(handle, "out of memory");
 
-	err:
+      err:
 	if (tmp_port != NULL) {
 		context_destroy(&tmp_port->context[0]);
 		free(tmp_port);
-        }
+	}
 	context_destroy(tmp_con);
 	free(tmp_con);
 	ERR(handle, "could not create port structure for range %u:%u (%s)",
-		low, high, sepol_port_get_proto_str(proto));
+	    low, high, sepol_port_get_proto_str(proto));
 	return STATUS_ERR;
 }
 
-static int port_to_record (
-	sepol_handle_t* handle,
-	const policydb_t* policydb,
-	ocontext_t* port,
-	sepol_port_t** record) {
+static int port_to_record(sepol_handle_t * handle,
+			  const policydb_t * policydb,
+			  ocontext_t * port, sepol_port_t ** record)
+{
 
 	int proto = port->u.port.protocol;
 	int low = port->u.port.low_port;
 	int high = port->u.port.high_port;
-	context_struct_t* con = &port->context[0];
+	context_struct_t *con = &port->context[0];
 	int rec_proto = -1;
 
-	sepol_context_t* tmp_con = NULL;
-	sepol_port_t* tmp_record = NULL;
+	sepol_context_t *tmp_con = NULL;
+	sepol_port_t *tmp_record = NULL;
 
 	if (sepol_port_create(handle, &tmp_record) < 0)
 		goto err;
@@ -137,26 +131,25 @@ static int port_to_record (
 	*record = tmp_record;
 	return STATUS_SUCCESS;
 
-	err:
+      err:
 	ERR(handle, "could not convert port range %u - %u (%s) "
-		"to record", low, high, sepol_port_get_proto_str(rec_proto));
+	    "to record", low, high, sepol_port_get_proto_str(rec_proto));
 	sepol_context_free(tmp_con);
 	sepol_port_free(tmp_record);
 	return STATUS_ERR;
 }
 
 /* Return the number of ports */
-extern int sepol_port_count(
-	sepol_handle_t* handle,
-	const sepol_policydb_t* p,
-	unsigned int* response) {
+extern int sepol_port_count(sepol_handle_t * handle,
+			    const sepol_policydb_t * p, unsigned int *response)
+{
 
 	unsigned int count = 0;
 	ocontext_t *c, *head;
-	const policydb_t* policydb = &p->p;
+	const policydb_t *policydb = &p->p;
 
 	head = policydb->ocontexts[OCON_PORT];
-	for (c =  head; c != NULL; c = c->next)
+	for (c = head; c != NULL; c = c->next)
 		count++;
 
 	*response = count;
@@ -166,17 +159,16 @@ extern int sepol_port_count(
 }
 
 /* Check if a port exists */
-int sepol_port_exists (
-	sepol_handle_t* handle,
-	const sepol_policydb_t* p,
-	const sepol_port_key_t* key,
-	int* response) {
+int sepol_port_exists(sepol_handle_t * handle,
+		      const sepol_policydb_t * p,
+		      const sepol_port_key_t * key, int *response)
+{
 
 	const policydb_t *policydb = &p->p;
 	ocontext_t *c, *head;
 
 	int low, high, proto;
-	const char* proto_str;
+	const char *proto_str;
 	sepol_port_key_unpack(key, &low, &high, &proto);
 	proto_str = sepol_port_get_proto_str(proto);
 	proto = sepol2ipproto(handle, proto);
@@ -198,24 +190,23 @@ int sepol_port_exists (
 	*response = 0;
 	return STATUS_SUCCESS;
 
-	err:
+      err:
 	ERR(handle, "could not check if port range %u - %u (%s) exists",
-		low, high, proto_str);
+	    low, high, proto_str);
 	return STATUS_ERR;
 }
 
 /* Query a port */
-int sepol_port_query(
-	sepol_handle_t* handle,
-	const sepol_policydb_t* p,
-	const sepol_port_key_t* key,
-	sepol_port_t** response) {
+int sepol_port_query(sepol_handle_t * handle,
+		     const sepol_policydb_t * p,
+		     const sepol_port_key_t * key, sepol_port_t ** response)
+{
 
 	const policydb_t *policydb = &p->p;
 	ocontext_t *c, *head;
 
 	int low, high, proto;
-	const char* proto_str;
+	const char *proto_str;
 	sepol_port_key_unpack(key, &low, &high, &proto);
 	proto_str = sepol_port_get_proto_str(proto);
 	proto = sepol2ipproto(handle, proto);
@@ -238,29 +229,28 @@ int sepol_port_query(
 	*response = NULL;
 	return STATUS_SUCCESS;
 
-	err: 
+      err:
 	ERR(handle, "could not query port range %u - %u (%s)",
-		low, high, proto_str);
+	    low, high, proto_str);
 	return STATUS_ERR;
 
 }
 
 /* Load a port into policy */
-int sepol_port_modify(
-	sepol_handle_t* handle,
-	sepol_policydb_t* p, 
-	const sepol_port_key_t* key,
-	const sepol_port_t* data) {
+int sepol_port_modify(sepol_handle_t * handle,
+		      sepol_policydb_t * p,
+		      const sepol_port_key_t * key, const sepol_port_t * data)
+{
 
 	policydb_t *policydb = &p->p;
 	ocontext_t *port = NULL;
 
 	int low, high, proto;
-	const char* proto_str;
+	const char *proto_str;
 
 	sepol_port_key_unpack(key, &low, &high, &proto);
 	proto_str = sepol_port_get_proto_str(proto);
-	proto = sepol2ipproto(handle, proto);	
+	proto = sepol2ipproto(handle, proto);
 	if (proto < 0)
 		goto err;
 
@@ -273,9 +263,9 @@ int sepol_port_modify(
 
 	return STATUS_SUCCESS;
 
-	err:
+      err:
 	ERR(handle, "could not load port range %u - %u (%s)",
-		low, high, proto_str);
+	    low, high, proto_str);
 	if (port != NULL) {
 		context_destroy(&port->context[0]);
 		free(port);
@@ -283,17 +273,15 @@ int sepol_port_modify(
 	return STATUS_ERR;
 }
 
-int sepol_port_iterate(
-	sepol_handle_t* handle,
-	const sepol_policydb_t* p,
-	int (*fn)(
-		const sepol_port_t* port,
-		void* fn_arg),
-	void* arg) {
+int sepol_port_iterate(sepol_handle_t * handle,
+		       const sepol_policydb_t * p,
+		       int (*fn) (const sepol_port_t * port,
+				  void *fn_arg), void *arg)
+{
 
 	const policydb_t *policydb = &p->p;
 	ocontext_t *c, *head;
-	sepol_port_t* port = NULL;	
+	sepol_port_t *port = NULL;
 
 	head = policydb->ocontexts[OCON_PORT];
 	for (c = head; c; c = c->next) {
@@ -302,22 +290,22 @@ int sepol_port_iterate(
 		if (port_to_record(handle, policydb, c, &port) < 0)
 			goto err;
 
-		/* Invoke handler */	
+		/* Invoke handler */
 		status = fn(port, arg);
 		if (status < 0)
 			goto err;
-		
+
 		sepol_port_free(port);
 		port = NULL;
 
 		/* Handler requested exit */
-		if (status > 0) 
+		if (status > 0)
 			break;
 	}
 
 	return STATUS_SUCCESS;
 
-	err:
+      err:
 	ERR(handle, "could not iterate over ports");
 	sepol_port_free(port);
 	return STATUS_ERR;
